@@ -104,6 +104,9 @@
 /* Define to 1 if you have the `curl_off_t' type. */
 #define HAVE_CURL_OFF_T 1
 
+/* Define to 1 if you have support for the CURLINFO_TLS_SSL_PTR feature. */
+#define HAVE_CURLINFO_TLS_SSL_PTR 1
+
 /* Name of package */
 #define PACKAGE "xmltooling"
 
@@ -114,13 +117,13 @@
 #define PACKAGE_NAME "xmltooling"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "xmltooling 1.5.6"
+#define PACKAGE_STRING "xmltooling 1.6.0"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "xmltooling"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "1.5.6"
+#define PACKAGE_VERSION "1.6.0"
 
 /* Define to the necessary symbol if this constant uses a non-standard name on
    your system. */
@@ -133,7 +136,7 @@
 /* #undef TM_IN_SYS_TIME */
 
 /* Version number of package */
-#define VERSION "1.5.6"
+#define VERSION "1.6.0"
 
 /* Define if you wish to disable XML-Security-dependent features. */
 /* #undef XMLTOOLING_NO_XMLSEC */
