@@ -73,6 +73,9 @@ namespace xmltooling {
         CURLSOAPTransport(const Address& addr)
             : m_sender(addr.m_from ? addr.m_from : ""), m_peerName(addr.m_to ? addr.m_to : ""), m_endpoint(addr.m_endpoint),
                 m_handle(nullptr), m_keepHandle(false), m_headers(nullptr),
+#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+                    m_cipherLogged(false),
+#endif
 #ifndef XMLTOOLING_NO_XMLSEC
                     m_cred(nullptr), m_trustEngine(nullptr), m_peerResolver(nullptr), m_mandatory(false),
 #endif
@@ -83,7 +86,7 @@ namespace xmltooling {
             curl_easy_setopt(m_handle,CURLOPT_CONNECTTIMEOUT,15);
             curl_easy_setopt(m_handle,CURLOPT_TIMEOUT,30);
             curl_easy_setopt(m_handle,CURLOPT_HTTPAUTH,0);
-            curl_easy_setopt(m_handle,CURLOPT_USERPWD,nullptr);
+            curl_easy_setopt(m_handle,CURLOPT_USERPWD,0);
             curl_easy_setopt(m_handle,CURLOPT_SSL_VERIFYHOST,2);
             curl_easy_setopt(m_handle,CURLOPT_HEADERDATA,this);
             m_headers=curl_slist_append(m_headers,"Content-Type: text/xml");
@@ -92,9 +95,9 @@ namespace xmltooling {
         virtual ~CURLSOAPTransport() {
             curl_slist_free_all(m_headers);
             if (m_keepHandle) {
-                curl_easy_setopt(m_handle, CURLOPT_USERAGENT, nullptr);
-                curl_easy_setopt(m_handle, CURLOPT_ERRORBUFFER, nullptr);
-                curl_easy_setopt(m_handle, CURLOPT_PRIVATE, m_authenticated ? "secure" : nullptr); // Save off security "state".
+                curl_easy_setopt(m_handle, CURLOPT_USERAGENT, 0);
+                curl_easy_setopt(m_handle, CURLOPT_ERRORBUFFER, 0);
+                curl_easy_setopt(m_handle, CURLOPT_PRIVATE, m_authenticated ? "secure" : 0); // Save off security "state".
                 g_CURLPool->put(m_sender.c_str(), m_peerName.c_str(), m_endpoint.c_str(), m_handle);
             }
             else {
@@ -208,6 +211,10 @@ namespace xmltooling {
             return true;
         }
 
+        bool setCipherSuites(const char* cipherlist) {
+            return (curl_easy_setopt(m_handle,CURLOPT_SSL_CIPHER_LIST,cipherlist)==CURLE_OK);
+        }
+
     private:
         // per-call state
         string m_sender,m_peerName,m_endpoint,m_simplecreds;
@@ -218,6 +225,9 @@ namespace xmltooling {
 		string m_useragent;
         map<string,vector<string> > m_response_headers;
         vector<string> m_saved_options;
+#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+        bool m_cipherLogged;
+#endif
 #ifndef XMLTOOLING_NO_XMLSEC
         const OpenSSLCredential* m_cred;
         const OpenSSLTrustEngine* m_trustEngine;
@@ -318,7 +328,7 @@ CURL* CURLPool::get(const SOAPTransport::Address& addr)
     curl_easy_setopt(handle,CURLOPT_SSL_CIPHER_LIST,"ALL:!aNULL:!LOW:!EXPORT:!RC4:!SSLv2");
     // Verification of the peer is via TrustEngine only.
     curl_easy_setopt(handle,CURLOPT_SSL_VERIFYPEER,0);
-    curl_easy_setopt(handle,CURLOPT_CAINFO,nullptr);
+    curl_easy_setopt(handle,CURLOPT_CAINFO,0);
     curl_easy_setopt(handle,CURLOPT_HEADERFUNCTION,&curl_header_hook);
     curl_easy_setopt(handle,CURLOPT_WRITEFUNCTION,&curl_write_hook);
     curl_easy_setopt(handle,CURLOPT_DEBUGFUNCTION,&curl_debug_hook);
@@ -371,7 +381,7 @@ bool CURLSOAPTransport::setAuth(transport_auth_t authType, const char* username,
     if (authType==transport_auth_none) {
         if (curl_easy_setopt(m_handle,CURLOPT_HTTPAUTH,0)!=CURLE_OK)
             return false;
-        return (curl_easy_setopt(m_handle,CURLOPT_USERPWD,nullptr)==CURLE_OK);
+        return (curl_easy_setopt(m_handle,CURLOPT_USERPWD,0)==CURLE_OK);
     }
     long flag=0;
     switch (authType) {
@@ -422,7 +432,7 @@ bool CURLSOAPTransport::setProviderOption(const char* provider, const char* opti
     else if (opt < CURLOPTTYPE_OFF_T) {
         if (value)
             m_saved_options.push_back(value);
-        return (curl_easy_setopt(m_handle, opt, value ? m_saved_options.back().c_str() : nullptr) == CURLE_OK);
+        return (curl_easy_setopt(m_handle, opt, value ? m_saved_options.back().c_str() : 0) == CURLE_OK);
     }
 # ifdef HAVE_CURL_OFF_T
     else if (sizeof(curl_off_t) == sizeof(long))
@@ -436,7 +446,7 @@ bool CURLSOAPTransport::setProviderOption(const char* provider, const char* opti
     else {
         if (value)
             m_saved_options.push_back(value);
-        return (curl_easy_setopt(m_handle, opt, value ? m_saved_options.back().c_str() : nullptr) == CURLE_OK);
+        return (curl_easy_setopt(m_handle, opt, value ? m_saved_options.back().c_str() : 0) == CURLE_OK);
     }
 #endif
 }
@@ -509,7 +519,7 @@ void CURLSOAPTransport::send(istream* in)
             msg.append(buf,in->gcount());
         }
         curl_easy_setopt(m_handle,CURLOPT_POST,1);
-        curl_easy_setopt(m_handle,CURLOPT_READFUNCTION,nullptr);
+        curl_easy_setopt(m_handle,CURLOPT_READFUNCTION,0);
         curl_easy_setopt(m_handle,CURLOPT_POSTFIELDS,msg.c_str());
         curl_easy_setopt(m_handle,CURLOPT_POSTFIELDSIZE,msg.length());
     }
@@ -562,13 +572,14 @@ void CURLSOAPTransport::send(istream* in)
             m_authenticated=true;
     }
     else {
-        curl_easy_setopt(m_handle,CURLOPT_SSL_CTX_FUNCTION,nullptr);
-        curl_easy_setopt(m_handle,CURLOPT_SSL_CTX_DATA,nullptr);
+        curl_easy_setopt(m_handle,CURLOPT_SSL_CTX_FUNCTION,0);
+        curl_easy_setopt(m_handle,CURLOPT_SSL_CTX_DATA,0);
     }
 
     // Make the call.
     log.debug("sending SOAP message to %s", m_endpoint.c_str());
     CURLcode code = curl_easy_perform(m_handle);
+
     if (code != CURLE_OK) {
         if (code == CURLE_SSL_CIPHER) {
             log.error("on Red Hat 6+, make sure libcurl used is built with OpenSSL");
@@ -592,10 +603,27 @@ void CURLSOAPTransport::send(istream* in)
 // callback to buffer headers from server
 size_t xmltooling::curl_header_hook(void* ptr, size_t size, size_t nmemb, void* stream)
 {
+    CURLSOAPTransport* ctx = reinterpret_cast<CURLSOAPTransport*>(stream);
+
+#ifdef HAVE_CURLINFO_TLS_SSL_PTR
+    if (!ctx->m_cipherLogged) {
+        Category& log = Category::getInstance(XMLTOOLING_LOGCAT ".SOAPTransport.CURL");
+        if (log.isDebugEnabled()) {
+            struct curl_tlssessioninfo* tlsinfo = nullptr;
+            CURLcode infocode = curl_easy_getinfo(ctx->m_handle, CURLINFO_TLS_SSL_PTR, &tlsinfo);
+            if (infocode == CURLE_OK && tlsinfo && tlsinfo->backend == CURLSSLBACKEND_OPENSSL && tlsinfo->internals) {
+                SSL* ssl = reinterpret_cast<SSL*>(tlsinfo->internals);
+                const SSL_CIPHER* cipher = SSL_get_current_cipher(ssl);
+                log.debug("SSL version: %s, cipher: %s", SSL_get_version(ssl), cipher ? SSL_CIPHER_get_name(cipher) : "unknown");
+            }
+        }
+        ctx->m_cipherLogged = true;
+    }
+#endif
+
     // only handle single-byte data
     if (size!=1)
         return 0;
-    CURLSOAPTransport* ctx = reinterpret_cast<CURLSOAPTransport*>(stream);
     char* buf = (char*)malloc(nmemb + 1);
     if (buf) {
         memset(buf,0,nmemb + 1);
@@ -648,7 +676,22 @@ int xmltooling::curl_debug_hook(CURL* handle, curl_infotype type, char* data, si
 int xmltooling::verify_callback(X509_STORE_CTX* x509_ctx, void* arg)
 {
     Category& log=Category::getInstance(XMLTOOLING_LOGCAT ".SOAPTransport.CURL");
-    log.debug("invoking custom X.509 verify callback");
+    if (log.isDebugEnabled()) {
+        log.debug("invoking custom X.509 verify callback");
+        SSL* ssl = reinterpret_cast<SSL*>(X509_STORE_CTX_get_ex_data(x509_ctx, SSL_get_ex_data_X509_STORE_CTX_idx()));
+        if (ssl) {
+            CategoryStream logstr = log.debugStream();
+            logstr << "ciphers offered by client";
+            for (int i = 0;; ++i) {
+                const char* p = SSL_get_cipher_list(ssl, i);
+                if (!p)
+                    break;
+                logstr << ':' << p;
+            }
+            logstr << eol;
+        }
+    }
+
 #if (OPENSSL_VERSION_NUMBER >= 0x00907000L)
     CURLSOAPTransport* ctx = reinterpret_cast<CURLSOAPTransport*>(arg);
 #else
